@@ -27,6 +27,10 @@ expect_invalid_attr_for_text = functools.partial(base_expect_invalid_attr_for_te
 
 
 class TestExtraInfoDescriptor(unittest.TestCase):
+  def test_from_str(self):
+    sig = RelayExtraInfoDescriptor.create()
+    self.assertEqual(sig, RelayExtraInfoDescriptor.from_str(str(sig)))
+
   def test_metrics_relay_descriptor(self):
     """
     Parses and checks our results against an extrainfo descriptor from metrics.
@@ -53,7 +57,8 @@ k0d2aofcVbHr4fPQOSST0LXDrhFl5Fqo5um296zpJGvRUeO6S44U/EfJAGShtqWw
     self.assertEqual(datetime.datetime(2012, 5, 5, 17, 2, 45), desc.dir_write_history_end)
     self.assertEqual(900, desc.dir_write_history_interval)
     self.assertEqual(expected_signature, desc.signature)
-    self.assertEqual('00A57A9AAB5EA113898E2DD02A755E31AFC27227', desc.digest())
+    self.assertEqual('00A57A9AAB5EA113898E2DD02A755E31AFC27227', desc.digest(stem.descriptor.DigestHash.SHA1))
+    self.assertEqual('n2+wh6uM+lbKnhbkOog2jv9X5tPytlrFdO+I+auSmME', desc.digest(stem.descriptor.DigestHash.SHA256, stem.descriptor.DigestEncoding.BASE64))
     self.assertEqual([], desc.get_unrecognized_lines())
 
     # The read-history, write-history, dirreq-read-history, and
@@ -72,6 +77,8 @@ k0d2aofcVbHr4fPQOSST0LXDrhFl5Fqo5um296zpJGvRUeO6S44U/EfJAGShtqWw
     dir_write_values_start = [0, 0, 0, 227328, 349184, 382976, 738304]
     self.assertEqual(dir_write_values_start, desc.dir_write_history_values[:7])
 
+    self.assertEqual('@type extra-info 1.0', str(desc.type_annotation()))
+
   def test_metrics_bridge_descriptor(self):
     """
     Parses and checks our results against an extrainfo bridge descriptor from
@@ -133,6 +140,8 @@ k0d2aofcVbHr4fPQOSST0LXDrhFl5Fqo5um296zpJGvRUeO6S44U/EfJAGShtqWw
     self.assertEqual({}, desc.dir_v2_responses_unknown)
     self.assertEqual({}, desc.dir_v2_responses_unknown)
 
+    self.assertEqual('@type bridge-extra-info 1.0', str(desc.type_annotation()))
+
   @test.require.cryptography
   def test_descriptor_signing(self):
     RelayExtraInfoDescriptor.create(sign = True)
