@@ -12,7 +12,9 @@ import posixpath
 import tempfile
 import unittest
 
-from stem.util import str_type, system
+import stem.prereq
+
+from stem.util import system
 
 try:
   # added in python 3.3
@@ -128,8 +130,7 @@ class TestSystem(unittest.TestCase):
     """
 
     # mock response with a linux and bsd resolver
-    running_commands = [str_type('irssi'), str_type('moc'), str_type('tor'),
-                        str_type('ps'), str_type('  firefox  ')]
+    running_commands = ['irssi', 'moc', 'tor', 'ps', '  firefox  ']
 
     for ps_cmd in (system.IS_RUNNING_PS_LINUX, system.IS_RUNNING_PS_BSD):
       call_mock.side_effect = mock_call(ps_cmd, running_commands)
@@ -155,9 +156,12 @@ class TestSystem(unittest.TestCase):
     Exercises the size_of function.
     """
 
-    self.assertTrue(system.size_of('') < system.size_of('hello') < system.size_of('hello world'))
-    self.assertTrue(system.size_of([]) < system.size_of(['hello']) < system.size_of(['hello', 'world']))
-    self.assertTrue(system.size_of({}) < system.size_of({'hello': 'world'}) < system.size_of({'hello': 'world', 'more': 'stuff'}))
+    if stem.prereq.is_pypy():
+      self.assertRaises(NotImplementedError, system.size_of, 'hello')
+    else:
+      self.assertTrue(system.size_of('') < system.size_of('hello') < system.size_of('hello world'))
+      self.assertTrue(system.size_of([]) < system.size_of(['hello']) < system.size_of(['hello', 'world']))
+      self.assertTrue(system.size_of({}) < system.size_of({'hello': 'world'}) < system.size_of({'hello': 'world', 'more': 'stuff'}))
 
   @patch('stem.util.system.call')
   @patch('stem.util.proc.is_available', Mock(return_value = False))
